bayespy.inference.vmp.nodes.categorical.CategoricalMoments.__init__
===================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical

.. automethod:: CategoricalMoments.__init__